@@ -4,7 +4,7 @@ __license__ = "Apache-2.0"
 from functools import wraps
 from typing import Callable
 
-from .. import Request
+from .. import Response
 from ..enums import CallbackOnType
 from ..excepts import BadClientCallback
 from ..helper import colored
@@ -12,11 +12,10 @@ from ..importer import ImportExtensions
 from ..proto import jina_pb2
 
 
-def pprint_routes(resp: 'Request', stack_limit: int = 3):
+def pprint_routes(resp: 'Response', stack_limit: int = 3):
     """Pretty print routes with :mod:`prettytable`, fallback to :func:`print`
 
-    :param routes: list of :class:`jina_pb2.RouteProto` objects from Envelop
-    :param status: the :class:`jina_pb2.StatusProto` object
+    :param resp: the :class:`Response` object
     :param stack_limit: traceback limit
     :return:
     """
@@ -26,7 +25,7 @@ def pprint_routes(resp: 'Request', stack_limit: int = 3):
 
     header = [colored(v, attrs=['bold']) for v in ('Pod', 'Time', 'Exception')]
 
-    # poorman solution
+    # poor-man solution
     table = []
 
     def add_row(x):
