@@ -161,6 +161,14 @@ def _make_hub_table(manifests):
                               f'{desc:<30s}')
     return info_table
 
+def _fetch_access_token(logger):
+    if not credentials_file().is_file():
+        logger.error(f'user has not logged in. please login using command: {colored("jina hub login", attrs=["bold"])}')
+        return
+    with open(credentials_file(), 'r') as cf:
+        cred_yml = JAML.load(cf)
+    access_token = cred_yml['access_token']
+    return access_token
 
 def _register_to_mongodb(logger, summary: Dict = None):
     """ Hub API Invocation to run `hub push` """
@@ -171,14 +179,7 @@ def _register_to_mongodb(logger, summary: Dict = None):
 
     hubapi_url = hubapi_yml['hubapi']['url'] + hubapi_yml['hubapi']['push']
 
-    if not credentials_file().is_file():
-        logger.error(f'user hasnot logged in. please login using command: {colored("jina hub login", attrs=["bold"])}')
-        return
-
-    with open(credentials_file(), 'r') as cf:
-        cred_yml = JAML.load(cf)
-    access_token = cred_yml['access_token']
-
+    access_token = _fetch_access_token(logger)
     if not access_token:
         logger.error(f'user has not logged in. please login using command: {colored("jina hub login", attrs=["bold"])}')
         return
