@@ -4,43 +4,58 @@ __license__ = "Apache-2.0"
 import time
 
 from . import BaseDriver
+from .querylang.queryset.dunderkey import dunder_get
 from ..excepts import UnknownControlCommand, RequestLoopEnd, NoExplicitMessage
 from ..proto import jina_pb2
 
 
-class ControlReqDriver(BaseDriver):
-    """Handling the control request, by default it is installed for all :class:`jina.peapods.pea.BasePea`"""
+class BaseControlDriver(BaseDriver):
+    """Control driver does not have access to the executor and it
+    often works directly with protobuf layer instead Jina primitive types"""
 
-    def __call__(self, *args, **kwargs):
-        if self.req.command == jina_pb2.Request.ControlRequest.TERMINATE:
-            self.envelope.status.code = jina_pb2.Status.SUCCESS
-            raise RequestLoopEnd
-        elif self.req.command == jina_pb2.Request.ControlRequest.STATUS:
-            self.envelope.status.code = jina_pb2.Status.READY
-            for k, v in vars(self.pea.args).items():
-                self.req.args[k] = str(v)
-        else:
-            raise UnknownControlCommand('don\'t know how to handle %s' % self.req)
+    @property
+    def envelope(self) -> 'jina_pb2.EnvelopeProto':
+        """Get the current request, shortcut to ``self.pea.message``"""
+        return self.msg.envelope
 
 
-class LogInfoDriver(BaseDriver):
+class LogInfoDriver(BaseControlDriver):
     """Log output the request info"""
 
-    def __init__(self, field: str = 'msg', *args, **kwargs):
+    def __init__(self, key: str = 'request', *args, **kwargs):
+        """
+        :param key: (str) that represents a first level or nested key in the dict
+        :param args:
+        :param kwargs:
+        """
         super().__init__(*args, **kwargs)
-        self.field = field
+        self.key = key
 
     def __call__(self, *args, **kwargs):
-        self.logger.info(getattr(self, self.field, 'msg'))
+        self.logger.info(dunder_get(self.msg.as_pb_object, self.key))
 
 
-class WaitDriver(BaseDriver):
-    """Wait for some seconds"""
+class WaitDriver(BaseControlDriver):
+    """Wait for some seconds, mainly for demo purpose"""
 
     def __call__(self, *args, **kwargs):
         time.sleep(5)
 
 
+class ControlReqDriver(BaseControlDriver):
+    """Handling the control request, by default it is installed for all :class:`jina.peapods.pea.BasePea`"""
+
+    def __call__(self, *args, **kwargs):
+        if self.req.command == 'TERMINATE':
+            self.envelope.status.code = jina_pb2.StatusProto.SUCCESS
+            raise RequestLoopEnd
+        elif self.req.command == 'STATUS':
+            self.envelope.status.code = jina_pb2.StatusProto.READY
+            self.req.args = vars(self.pea.args)
+        else:
+            raise UnknownControlCommand(f'don\'t know how to handle {self.req.command}')
+
+
 class RouteDriver(ControlReqDriver):
     """A simple load balancer forward message to the next available pea
 
@@ -90,7 +105,7 @@ class RouteDriver(ControlReqDriver):
             # all the time
             # (2) this driver is used in a ROUTER-DEALER fan-out setting,
             # where some dealer is broken/fails to start, so `idle_dealer_ids` is empty
-        elif self.req.command == jina_pb2.Request.ControlRequest.IDLE:
+        elif self.req.command == 'IDLE':
             self.idle_dealer_ids.add(self.envelope.receiver_id)
             self.logger.debug(f'{self.envelope.receiver_id} is idle')
             if self.is_pollin_paused:
@@ -103,3 +118,7 @@ class RouteDriver(ControlReqDriver):
 
 class ForwardDriver(RouteDriver):
     """Alias to :class:`RouteDriver`"""
+
+
+class ReduceDriver(RouteDriver):
+    """Alias to :class:`RouteDriver`"""
