@@ -8,9 +8,7 @@ class RecallEvaluator(BaseRankingEvaluator):
        It computes how many of the first given `eval_at` groundtruth are found in the matches
     """
 
-    @property
-    def metric(self):
-        return f'Recall@{self.eval_at}'
+    metric = 'Recall@N'
 
     def evaluate(self, actual: Sequence[Any], desired: Sequence[Any], *args, **kwargs) -> float:
         """"
@@ -18,13 +16,5 @@ class RecallEvaluator(BaseRankingEvaluator):
         :param desired: the expected documents matches ids sorted as they are expected
         :return the evaluation metric value for the request document
         """
-        if not desired:
-            """TODO: Agree on a behavior"""
-            return 0.0
-
-        ret = 0.0
-        for doc_id in actual[:self.eval_at]:
-            if doc_id in desired:
-                ret += 1.0
-
+        ret = len(set(actual).intersection(set(desired)))
         return ret / len(desired)
